Weblate basics
==============

Projects structure
------------------

Each project can contain various components. The reason for this structure is
that all components in a project are expected to have a lot in common.
Whenever translation is made in single component, it is automatically
propagated to others within same project (this is especially useful when
translating more version of same project, but can be disabled, see
:ref:`component`).
